/******************************************************************************
*
* Copyright (C) 2009 - 2014 Xilinx, Inc.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* Use of the Software is limited solely to applications:
* (a) running on a Xilinx device, or
* (b) that interact with a Xilinx device through a bus or interconnect.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Except as contained in this notice, the name of the Xilinx shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Xilinx.
*
******************************************************************************/

/*
 * helloworld.c: simple test application
 *
 * This application configures UART 16550 to baud rate 9600.
 * PS7 UART (Zynq) is not initialized by this application, since
 * bootrom/bsp configures it to baud rate 115200
 *
 * ------------------------------------------------
 * | UART TYPE   BAUD RATE                        |
 * ------------------------------------------------
 *   uartns550   9600
 *   uartlite    Configurable only in HW design
 *   ps7_uart    115200 (configured by bootrom/bsp)
 */

#include "xparameters.h"
#include "xrfdc.h"
#ifdef XPS_BOARD_ZCU111
#include "xrfdc_clk.h"
#include "xrfdc_clk.c"
#endif
/************************** Constant Definitions ****************************/

/*
 * The following constants map to the XPAR parameters created in the
 * xparameters.h file. They are defined here such that a user can easily
 * change all the needed parameters in one place.
 */
#define RFDC_DEVICE_ID 	XPAR_XRFDC_0_DEVICE_ID

#ifndef __BAREMETAL__
#define BUS_NAME        "platform"
#define RFDC_DEV_NAME    XPAR_XRFDC_0_DEV_NAME
#endif
#define ENABLE_METAL_PRINTS
/**************************** Type Definitions ******************************/


/***************** Macros (Inline Functions) Definitions ********************/
#ifdef __BAREMETAL__
#define printf xil_printf
#endif

static XRFdc RFdcInst;      /* RFdc driver instance */
#ifdef XPS_BOARD_ZCU111
unsigned int LMK04208_CKin[1][26] = {
		{0x00160040,0x80140320,0x80140321,0x80140322,
		0xC0140023,0x40140024,0x80141E05,0x03300006,0x01300007,0x06010008,
		0x55555549,0x9102410A,0x0401100B,0x1B0C006C,0x2302886D,0x0200000E,
		0x8000800F,0xC1550410,0x00000058,0x02C9C419,0x8FA8001A,0x10001E1B,
		0x0021201C,0x0180033D,0x0200033E,0x003F001F }};
#endif

/************************** Function Prototypes ******************************/

void my_metal_default_log_handler(enum metal_log_level level,
			       const char *format, ...);

/*****************************************************************************/


int main()
{
	int Status;
	XRFdc_Config *ConfigPtr;
	XRFdc *RFdcInstPtr = &RFdcInst;
	XRFdc_BlockStatus BlockStatus;
	XRFdc_IPStatus myIPStatus;

	XRFdc_Mixer_Settings MixerSettings = {0};


#ifdef ENABLE_METAL_PRINTS
	struct metal_init_params init_param = {	\
			.log_handler	= my_metal_default_log_handler,	\
			.log_level		= METAL_LOG_DEBUG,			\
	};

	if (metal_init(&init_param)) {
		xil_printf("ERROR: Failed to run metal initialization\n");
		return XRFDC_FAILURE;
	}
#endif

	/* Initialize the RFdc driver. */
	ConfigPtr = XRFdc_LookupConfig(RFDC_DEVICE_ID);
	if (ConfigPtr == NULL) {
		return XRFDC_FAILURE;
	}

	/* Initializes the controller */
	Status = XRFdc_CfgInitialize(RFdcInstPtr, ConfigPtr);
	if (Status != XRFDC_SUCCESS) {
		return XRFDC_FAILURE;
	}

    printf("Hello RFDC!\n\r");


    #ifdef XPS_BOARD_ZCU111
	printf("\n Configuring the Clock \r\n");
	#ifdef __BAREMETAL__
		LMK04208ClockConfig(1, LMK04208_CKin);
		LMX2594ClockConfig(1, 245760);
	#else
		LMK04208ClockConfig(12, LMK04208_CKin);
		LMX2594ClockConfig(12, 245760);
	#endif
	#endif

    sleep(10);
	
	Status = XRFdc_GetIPStatus(RFdcInstPtr, &myIPStatus);
		      if (Status != XRFDC_SUCCESS) {
			  return XRFDC_FAILURE;
			  }

    int powerup_status;
    int tile_state;
    powerup_status = myIPStatus.ADCTileStatus[0].PowerUpState;
    tile_state = myIPStatus.ADCTileStatus[0].TileState;

    printf("ADC PowerUp Status: %u\n", powerup_status);
    printf("ADC Tile State: %u\n", tile_state);


    int whole, thousandths; /* will need these for the doubles not supported by xil_printf*/

    /*print out the ADC status*/
	Status = XRFdc_GetBlockStatus(RFdcInstPtr, XRFDC_ADC_TILE, 0, 0, &BlockStatus);
					if (Status != XRFDC_SUCCESS) {
						return XRFDC_FAILURE;
					}

    whole = BlockStatus.SamplingFreq;
    thousandths = (BlockStatus.SamplingFreq - whole) * 1000;
    printf("ADC Sampling Frequency: %d.%3d\n",whole,thousandths);


	printf("\n ADC%d%d Status \n"
	"AnalogDataPathStatus - %u \nDigitalDataPathStatus - %u\nDataPathClockStatus - %u\nIsFIFOFlagsEnabled - %u\nIsFIFOFlagsAsserted - %u\n", 0, 0, BlockStatus.AnalogDataPathStatus, BlockStatus.DigitalDataPathStatus, BlockStatus.DataPathClocksStatus,
	 BlockStatus.IsFIFOFlagsEnabled, BlockStatus.IsFIFOFlagsAsserted);

    

	Status = XRFdc_GetMixerSettings(RFdcInstPtr, XRFDC_ADC_TILE, 0, 0, &MixerSettings);
					if (Status != XRFDC_SUCCESS) {
						return XRFDC_FAILURE;
					}

	whole = MixerSettings.Freq;
	thousandths = (MixerSettings.Freq - whole) * 1000;
	printf("ADC Mixer Frequency: %d.%3d\n",whole,thousandths);

	printf("\n ADC%d%d Mixer Scale\n"
	"FineMixerScale - %u\n", 0,0, MixerSettings.FineMixerScale);

	MixerSettings.Freq = -400;

	MixerSettings.FineMixerScale = XRFDC_MIXER_SCALE_1P0;

	MixerSettings.EventSource = XRFDC_EVNT_SRC_TILE;

	Status = XRFdc_SetMixerSettings(RFdcInstPtr, XRFDC_ADC_TILE, 0, 0, &MixerSettings);
					if (Status != XRFDC_SUCCESS) {
						return XRFDC_FAILURE;
					}

	/*generate a tile Event to apply it*/
    Status = XRFdc_UpdateEvent(RFdcInstPtr, XRFDC_ADC_TILE, 0, 0, XRFDC_EVENT_MIXER);
                    if (Status != XRFDC_SUCCESS) {
    				    return XRFDC_FAILURE;
    				}

	Status = XRFdc_GetMixerSettings(RFdcInstPtr, XRFDC_ADC_TILE, 0, 0, &MixerSettings);
					if (Status != XRFDC_SUCCESS) {
						return XRFDC_FAILURE;
					}

	printf("\n ADC%d%d New Mixer Scale \n"
	"FineMixerScale - %u\n", 0,0, MixerSettings.FineMixerScale);

	whole = MixerSettings.Freq;
	thousandths = (MixerSettings.Freq - whole) * 1000;
	printf("ADC Mixer Frequency: %d.%3d\n",whole,thousandths);
	
}


/*****************************************************************************/
/**
*
* My libmetal logger
*
******************************************************************************/
#include <stdarg.h>
#include <stdio.h>

#include <metal/log.h>
#include "metal/sys.h"

void my_metal_default_log_handler(enum metal_log_level level,
			       const char *format, ...)
{
	char msg[1024];
	char msgOut[1048];
	char *outPtr;
	int i;

	va_list args;
	static const char *level_strs[] = {
		"metal: emergency: ",
		"metal: alert:     ",
		"metal: critical:  ",
		"metal: error:     ",
		"metal: warning:   ",
		"metal: notice:    ",
		"metal: info:      ",
		"metal: debug:     ",
	};

	va_start(args, format);
	vsnprintf(msg, sizeof(msg), format, args);
	va_end(args);

	//replace single \n with \n\r
	outPtr = msgOut;
	for(i=0; i<1024; i++) {
		// if /n/r or /r/n combo
		if ((msg[i] == '\r' && msg[i+1] == '\n') ||
				(msg[i] == '\n' && msg[i+1] == '\r')) {
			*outPtr++ = msg[i++];
		} else if(msg[i] == '\n') {
			//if first char in string is \n, then remove
			if(i==0) {
				continue;
			} else {
				*outPtr++ = '\r';
			}
		}
		*outPtr++ = msg[i];
		if(msg[i] == 0) {
			break;
		}
	}
	//if line doesn't end with \n\r, then add it
	if( (msg[i-1] != '\n') && (msg[i-1] != '\r') ) {
		*(outPtr-1) = '\r';
		*outPtr++ = '\n';
		*outPtr++ = 0;
	}

	if (level <= METAL_LOG_EMERGENCY || level > METAL_LOG_DEBUG)
		level = METAL_LOG_EMERGENCY;

	xil_printf("%s%s", level_strs[level], msgOut);
}


